var languageNames = {
"en-US": "Inglés (EUA)",
"sq": "Albanés",
"am": "Amhárico",
"ar": "Árabe",
"ast": "Asturiano",
"bn": "Bengalí",
"bn-IN": "Bengalí (India)",
"bs": "Bosnio",
"bg": "Búlgaro",
"ca": "Catalán",
"ca-valencia": "Catalán (Valencia)",
"zh-CN": "Chinés (Simplificado)",
"zh-TW": "Chinés (Tradicional)",
"hr": "Croata",
"cs": "Checo",
"da": "Dinamarqués",
"nl": "Holandés",
"dz": "Dzongkha",
"en-GB": "Inglés (Reino Unido)",
"en-ZA": "Inglés (Sudáfrica)",
"eo": "Esperanto",
"et": "Estoniano",
"eu": "Éuscaro",
"fi": "Finlandés",
"fr": "Francés",
"gl": "Galego",
"ka": "Xeorxiano",
"de": "Alemán",
"el": "Grego",
"gu": "Guxaratí",
"he": "Hebreo",
"hi": "Hindi",
"hu": "Húngaro",
"id": "Indonesio",
"is": "Islandés",
"it": "Italiano",
"ja": "Xaponés",
"km": "Khmer",
"ko": "Coreano",
"lo": "Laosiano",
"lv": "Letón",
"lt": "Lituano",
"mk": "Macedonio",
"ne": "Nepalí",
"nn": "Noruegués Nynorsk",
"nb": "Noruegués Bokmål",
"om": "Oromo",
"pl": "Polaco",
"pt": "Portugués",
"pt-BR": "Portugués (Brasil)",
"ro": "Romanés",
"ru": "Ruso",
"sid": "Sidama",
"si": "Sinhala",
"sk": "Eslovaco",
"sl": "Esloveno",
"dsb": "Sorbio (Baixo)",
"hsb": "Sorbio (Alto)",
"es": "Castelán",
"sv": "Sueco",
"tg": "Taxico",
"ta": "Tamil",
"bo": "Tibetano",
"tr": "Turco",
"ug": "Uigur",
"uk": "Ucraíno",
"vi": "Vietnamita",
};
